#
# spec file for package nfpm
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           nfpm
Version:        2.40.0
Release:        1.1
Summary:        Simple deb, rpm, apk and arch linux packager written in Go
License:        MIT
URL:            https://github.com/goreleaser/nfpm
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22

%description
nFPM is a simple and 0-dependencies deb, rpm, apk and arch linux packager
written in Go

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X main.version=%{version} \
   -X main.commit=${COMMIT_HASH} \
   -X main.date=${BUILD_DATE} \
   -X main.builtBy=OBS \
   -X main.treeState=false" \
   -o bin/%{name} ./cmd/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%files
%doc README.md
%license LICENSE.md
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.40.0:
  * feat(deps): bump github.com/Masterminds/semver/v3 from 3.2.1 to
    3.3.0 (#852)
  * chore(deps): bump anchore/sbom-action from 0.17.1 to 0.17.2
    (#851)
  * feat(deps): bump dario.cat/mergo from 1.0.0 to 1.0.1 (#850)
  * feat(deb): set license field (#849)
  * docs: update cmd docs
* Fri Aug 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.39.0:
  * build: fix packagers shell on darwin
  * feat: env var substitution in description (#848)
  * build: update flake.nix
  * chore(deps): bump anchore/sbom-action from 0.17.0 to 0.17.1
    (#846)
  * chore(deps): bump sigstore/cosign-installer from 3.5.0 to 3.6.0
    (#845)
  * chore(deps): bump benc-uk/workflow-dispatch from 1.2.3 to 1.2.4
    (#844)
  * chore(deps): bump anchore/sbom-action from 0.16.1 to 0.17.0
    (#843)
  * chore(deps): bump anchore/sbom-action from 0.16.0 to 0.16.1
    (#842)
  * fix(deb): dpkg-sig format (#841)
  * docs: update cmd docs
* Wed Jul 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.38.0:
  * docs: clarify trailing slash in dst
  * fix: system fs paths on windows (#838)
  * test: centos8 mirrorlist has been down for a long time (#837)
  * fix: rpm doesnt allow dashes in prerelease (#836)
  * fix: better handle files owned by the fs (#834)
  * chore: cleanup
  * docs: update
  * docs: update
  * feat(deps): bump github.com/spf13/cobra from 1.8.0 to 1.8.1
    (#832)
  * feat(deps): bump github.com/klauspost/compress from 1.17.8 to
    1.17.9 (#831)
  * ci: update goreleaser config
  * chore(deps): bump goreleaser/goreleaser-action from 5 to 6
    (#827)
  * chore(deps): bump cachix/install-nix-action from 26 to 27
    (#823)
  * docs: update cmd docs
* Mon Jun 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.37.1:
  * fix: move mod back to go 1.21
  * docs: update cmd docs
  * test: test enumarate
  * chore(deps): update go-rpmutils (#814)
  * docs: update cmd docs
  * feat: support for ipk packages (#818)
  * chore(deps): update go-rpmutils
  * chore(deps): bump golangci/golangci-lint-action from 5 to 6
    (#819)
  * chore(deps): bump anchore/sbom-action from 0.15.10 to 0.15.11
    (#817)
  * chore(deps): bump golangci/golangci-lint-action from 4 to 5
    (#816)
* Mon Jun 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package nfpm: a simple deb, rpm, apk and arch linux packager
  written in Go
